diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/flyingAgentGUI.pro b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/flyingAgentGUI.pro
index 69b605354323c0c3aed13772053086e1c19a98be..529942c8ac112c59a1de472de706e7ef463a0986 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/flyingAgentGUI.pro
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/flyingAgentGUI.pro
@@ -28,7 +28,9 @@ SOURCES += src/main.cpp\
     src/studentcontrollertab.cpp \
     src/defaultcontrollertab.cpp \
     src/pickercontrollertab.cpp \
-    src/tuningcontrollertab.cpp
+    src/templatecontrollertab.cpp \
+    src/tuningcontrollertab.cpp \
+
 
 HEADERS  += include/mainwindow.h \
     include/topbanner.h \
@@ -41,8 +43,10 @@ HEADERS  += include/mainwindow.h \
     include/studentcontrollertab.h \
     include/defaultcontrollertab.h \
     include/pickercontrollertab.h \
+    include/templatecontrollertab.h \
     include/tuningcontrollertab.h \
-    include/Constants_for_Qt_compile.h
+    include/Constants_for_Qt_compile.h \
+
 
 
 FORMS    += forms/mainwindow.ui \
@@ -56,7 +60,9 @@ FORMS    += forms/mainwindow.ui \
     forms/studentcontrollertab.ui \
     forms/defaultcontrollertab.ui \
     forms/pickercontrollertab.ui \
-    forms/tuningcontrollertab.ui
+    forms/templatecontrollertab.ui \
+    forms/tuningcontrollertab.ui \
+
 
 RESOURCES += \
     flyingagentgui.qrc
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/controllertabs.ui b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/controllertabs.ui
index 75157907ea4645a83050ec0241e4a760d168dee8..471a55f3a30fb3afa2075720f8a66d6dfaf53a66 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/controllertabs.ui
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/controllertabs.ui
@@ -28,7 +28,7 @@
    <item row="0" column="0">
     <widget class="QTabWidget" name="controller_tabs_widget">
      <property name="currentIndex">
-      <number>3</number>
+      <number>4</number>
      </property>
      <property name="movable">
       <bool>true</bool>
@@ -73,13 +73,13 @@
        </item>
       </layout>
      </widget>
-     <widget class="QWidget" name="safe_tab">
+     <widget class="QWidget" name="template_tab">
       <attribute name="title">
-       <string>Safe</string>
+       <string>Template</string>
       </attribute>
-      <layout class="QGridLayout" name="gridLayout_3">
+      <layout class="QGridLayout" name="gridLayout_7">
        <item row="0" column="0">
-        <widget class="SafeControllerTab" name="safe_controller_tab_widget" native="true"/>
+        <widget class="TemplateControllerTab" name="template_controller_tab_widget" native="true"/>
        </item>
       </layout>
      </widget>
@@ -88,12 +88,6 @@
   </layout>
  </widget>
  <customwidgets>
-  <customwidget>
-   <class>SafeControllerTab</class>
-   <extends>QWidget</extends>
-   <header>safecontrollertab.h</header>
-   <container>1</container>
-  </customwidget>
   <customwidget>
    <class>StudentControllerTab</class>
    <extends>QWidget</extends>
@@ -118,6 +112,12 @@
    <header>tuningcontrollertab.h</header>
    <container>1</container>
   </customwidget>
+  <customwidget>
+   <class>TemplateControllerTab</class>
+   <extends>QWidget</extends>
+   <header>templatecontrollertab.h</header>
+   <container>1</container>
+  </customwidget>
  </customwidgets>
  <resources/>
  <connections/>
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/enablecontrollerloadyamlbar.ui b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/enablecontrollerloadyamlbar.ui
index b11f354ff419afaed713d41f3c2ca50627b451e1..c358d8befac4a77bff9b211af6cdb3eb9d2fd32c 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/enablecontrollerloadyamlbar.ui
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/enablecontrollerloadyamlbar.ui
@@ -109,7 +109,7 @@
       </spacer>
      </item>
      <item row="0" column="5">
-      <widget class="QPushButton" name="enable_safe_button">
+      <widget class="QPushButton" name="enable_template_button">
        <property name="sizePolicy">
         <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
          <horstretch>0</horstretch>
@@ -135,7 +135,7 @@
         </font>
        </property>
        <property name="text">
-        <string>Safe</string>
+        <string>Template</string>
        </property>
       </widget>
      </item>
@@ -255,7 +255,7 @@
       </widget>
      </item>
      <item row="1" column="5">
-      <widget class="QPushButton" name="load_yaml_safe_button">
+      <widget class="QPushButton" name="load_yaml_template_button">
        <property name="sizePolicy">
         <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
          <horstretch>0</horstretch>
@@ -275,7 +275,7 @@
         </size>
        </property>
        <property name="text">
-        <string>Safe</string>
+        <string>Template</string>
        </property>
       </widget>
      </item>
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/mainwindow.ui b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/mainwindow.ui
index 2a7f180b21fb15a87ae9950dc0e0359f5e3c35cf..bd79177a79d05cb8d14f5976d1ea5ab25cf9cd40 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/mainwindow.ui
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/mainwindow.ui
@@ -214,7 +214,7 @@
     <addaction name="action_showHideController_student"/>
     <addaction name="action_showHideController_picker"/>
     <addaction name="action_showHideController_tuning"/>
-    <addaction name="action_showHideController_safe"/>
+    <addaction name="action_showHideController_template"/>
    </widget>
    <addaction name="menuFile"/>
    <addaction name="menuLoad_YAML"/>
@@ -302,6 +302,17 @@
     <string>Tuning</string>
    </property>
   </action>
+  <action name="action_showHideController_template">
+   <property name="checkable">
+    <bool>true</bool>
+   </property>
+   <property name="checked">
+    <bool>true</bool>
+   </property>
+   <property name="text">
+    <string>Template</string>
+   </property>
+  </action>
  </widget>
  <layoutdefault spacing="6" margin="11"/>
  <customwidgets>
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/templatecontrollertab.ui b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/templatecontrollertab.ui
new file mode 100644
index 0000000000000000000000000000000000000000..fd7da271ecfde4eaa3e4e7a9a6d977288348aca2
--- /dev/null
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/forms/templatecontrollertab.ui
@@ -0,0 +1,872 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<ui version="4.0">
+ <class>TemplateControllerTab</class>
+ <widget class="QWidget" name="TemplateControllerTab">
+  <property name="geometry">
+   <rect>
+    <x>0</x>
+    <y>0</y>
+    <width>1335</width>
+    <height>937</height>
+   </rect>
+  </property>
+  <property name="font">
+   <font>
+    <pointsize>16</pointsize>
+   </font>
+  </property>
+  <property name="windowTitle">
+   <string>Form</string>
+  </property>
+  <layout class="QGridLayout" name="gridLayout_2">
+   <item row="2" column="0">
+    <spacer name="verticalSpacer_2">
+     <property name="orientation">
+      <enum>Qt::Vertical</enum>
+     </property>
+     <property name="sizeType">
+      <enum>QSizePolicy::Fixed</enum>
+     </property>
+     <property name="sizeHint" stdset="0">
+      <size>
+       <width>20</width>
+       <height>20</height>
+      </size>
+     </property>
+    </spacer>
+   </item>
+   <item row="4" column="0">
+    <spacer name="verticalSpacer">
+     <property name="orientation">
+      <enum>Qt::Vertical</enum>
+     </property>
+     <property name="sizeHint" stdset="0">
+      <size>
+       <width>20</width>
+       <height>40</height>
+      </size>
+     </property>
+    </spacer>
+   </item>
+   <item row="3" column="0">
+    <layout class="QGridLayout" name="gridLayout_3">
+     <property name="topMargin">
+      <number>6</number>
+     </property>
+     <property name="bottomMargin">
+      <number>6</number>
+     </property>
+     <item row="0" column="3">
+      <spacer name="horizontalSpacer">
+       <property name="orientation">
+        <enum>Qt::Horizontal</enum>
+       </property>
+       <property name="sizeHint" stdset="0">
+        <size>
+         <width>40</width>
+         <height>20</height>
+        </size>
+       </property>
+      </spacer>
+     </item>
+     <item row="0" column="1">
+      <widget class="QPushButton" name="pushButton_2">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="Minimum" vsizetype="Fixed">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="text">
+        <string>Button 2</string>
+       </property>
+      </widget>
+     </item>
+     <item row="0" column="2">
+      <widget class="QPushButton" name="pushButton_3">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="Minimum" vsizetype="Fixed">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="text">
+        <string>Button 3</string>
+       </property>
+      </widget>
+     </item>
+     <item row="0" column="0">
+      <widget class="QPushButton" name="pushButton">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="Minimum" vsizetype="Fixed">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="text">
+        <string>Button 1</string>
+       </property>
+      </widget>
+     </item>
+     <item row="1" column="2">
+      <layout class="QHBoxLayout" name="horizontalLayout_2">
+       <property name="leftMargin">
+        <number>0</number>
+       </property>
+       <property name="rightMargin">
+        <number>0</number>
+       </property>
+       <item>
+        <widget class="QLineEdit" name="lineEdit_9">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>16777215</width>
+           <height>16777215</height>
+          </size>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="1" column="1">
+      <layout class="QHBoxLayout" name="horizontalLayout_3">
+       <property name="leftMargin">
+        <number>0</number>
+       </property>
+       <property name="rightMargin">
+        <number>0</number>
+       </property>
+       <item>
+        <widget class="QLineEdit" name="lineEdit_8">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>16777215</width>
+           <height>16777215</height>
+          </size>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="1" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_4">
+       <property name="leftMargin">
+        <number>0</number>
+       </property>
+       <property name="rightMargin">
+        <number>0</number>
+       </property>
+       <item>
+        <widget class="QLineEdit" name="lineEdit_7">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>16777215</width>
+           <height>16777215</height>
+          </size>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+    </layout>
+   </item>
+   <item row="1" column="0">
+    <widget class="Line" name="line">
+     <property name="orientation">
+      <enum>Qt::Horizontal</enum>
+     </property>
+    </widget>
+   </item>
+   <item row="0" column="0">
+    <layout class="QGridLayout" name="gridLayout">
+     <item row="3" column="3">
+      <widget class="QLineEdit" name="lineEdit_15">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string/>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="1" column="3">
+      <widget class="QLabel" name="label_12">
+       <property name="text">
+        <string>Setpoint</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="5" column="2">
+      <widget class="QLineEdit" name="lineEdit_13">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string>xx.xx</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+       <property name="readOnly">
+        <bool>true</bool>
+       </property>
+      </widget>
+     </item>
+     <item row="2" column="1">
+      <widget class="QLabel" name="label_row_x">
+       <property name="text">
+        <string>x [m]</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="0" column="3">
+      <widget class="QLabel" name="label_11">
+       <property name="font">
+        <font>
+         <weight>75</weight>
+         <bold>true</bold>
+        </font>
+       </property>
+       <property name="text">
+        <string>New</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="0" column="4">
+      <spacer name="horizontalSpacer_2">
+       <property name="orientation">
+        <enum>Qt::Horizontal</enum>
+       </property>
+       <property name="sizeHint" stdset="0">
+        <size>
+         <width>40</width>
+         <height>20</height>
+        </size>
+       </property>
+      </spacer>
+     </item>
+     <item row="3" column="2">
+      <widget class="QLineEdit" name="lineEdit_11">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string>xx.xx</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+       <property name="readOnly">
+        <bool>true</bool>
+       </property>
+      </widget>
+     </item>
+     <item row="0" column="0">
+      <widget class="QLabel" name="label_measured_title">
+       <property name="font">
+        <font>
+         <weight>75</weight>
+         <bold>true</bold>
+        </font>
+       </property>
+       <property name="text">
+        <string>Measured</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="4" column="3">
+      <widget class="QLineEdit" name="lineEdit_16">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string/>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="4" column="2">
+      <widget class="QLineEdit" name="lineEdit_12">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string>xx.xx</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+       <property name="readOnly">
+        <bool>true</bool>
+       </property>
+      </widget>
+     </item>
+     <item row="3" column="1">
+      <widget class="QLabel" name="label_row_y">
+       <property name="text">
+        <string>y [m]</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="1" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_5">
+       <property name="spacing">
+        <number>0</number>
+       </property>
+       <item>
+        <widget class="QFrame" name="red_frame_position_left">
+         <property name="maximumSize">
+          <size>
+           <width>10</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="styleSheet">
+          <string notr="true">background-color:red;</string>
+         </property>
+         <property name="frameShape">
+          <enum>QFrame::StyledPanel</enum>
+         </property>
+         <property name="frameShadow">
+          <enum>QFrame::Raised</enum>
+         </property>
+        </widget>
+       </item>
+       <item>
+        <widget class="QLabel" name="label_measured_title_line2">
+         <property name="text">
+          <string>Position</string>
+         </property>
+         <property name="alignment">
+          <set>Qt::AlignCenter</set>
+         </property>
+        </widget>
+       </item>
+       <item>
+        <widget class="QFrame" name="red_frame_position_right">
+         <property name="maximumSize">
+          <size>
+           <width>10</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="styleSheet">
+          <string notr="true">background-color:red;</string>
+         </property>
+         <property name="frameShape">
+          <enum>QFrame::StyledPanel</enum>
+         </property>
+         <property name="frameShadow">
+          <enum>QFrame::Raised</enum>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="4" column="1">
+      <widget class="QLabel" name="label_row_z">
+       <property name="text">
+        <string>z [m]</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="2" column="2">
+      <widget class="QLineEdit" name="lineEdit_10">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string>xx.xx</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+       <property name="readOnly">
+        <bool>true</bool>
+       </property>
+      </widget>
+     </item>
+     <item row="5" column="3">
+      <widget class="QLineEdit" name="lineEdit_17">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string/>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="5" column="1">
+      <widget class="QLabel" name="label_row_yaw">
+       <property name="text">
+        <string>yaw [deg]</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="6" column="3">
+      <widget class="QPushButton" name="pushButton_5">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="text">
+        <string>Set New</string>
+       </property>
+      </widget>
+     </item>
+     <item row="0" column="2">
+      <widget class="QLabel" name="label_9">
+       <property name="font">
+        <font>
+         <weight>75</weight>
+         <bold>true</bold>
+        </font>
+       </property>
+       <property name="text">
+        <string>Current</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="6" column="1">
+      <widget class="QLabel" name="label_row_pitch">
+       <property name="text">
+        <string>pitch [deg]</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="2" column="3">
+      <widget class="QLineEdit" name="lineEdit_14">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="font">
+        <font>
+         <family>Courier</family>
+        </font>
+       </property>
+       <property name="text">
+        <string/>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="1" column="2">
+      <widget class="QLabel" name="label_10">
+       <property name="text">
+        <string>Setpoint</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="6" column="2">
+      <widget class="QPushButton" name="pushButton_4">
+       <property name="sizePolicy">
+        <sizepolicy hsizetype="MinimumExpanding" vsizetype="MinimumExpanding">
+         <horstretch>0</horstretch>
+         <verstretch>0</verstretch>
+        </sizepolicy>
+       </property>
+       <property name="maximumSize">
+        <size>
+         <width>180</width>
+         <height>60</height>
+        </size>
+       </property>
+       <property name="text">
+        <string>Default</string>
+       </property>
+      </widget>
+     </item>
+     <item row="7" column="1">
+      <widget class="QLabel" name="label_row_roll">
+       <property name="text">
+        <string>roll [deg]</string>
+       </property>
+       <property name="alignment">
+        <set>Qt::AlignCenter</set>
+       </property>
+      </widget>
+     </item>
+     <item row="2" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_7">
+       <item>
+        <widget class="QLineEdit" name="lineEdit_measured_x">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>180</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="font">
+          <font>
+           <family>Courier</family>
+          </font>
+         </property>
+         <property name="text">
+          <string>xx.xx</string>
+         </property>
+         <property name="alignment">
+          <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+         </property>
+         <property name="readOnly">
+          <bool>true</bool>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="3" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_8">
+       <item>
+        <widget class="QLineEdit" name="lineEdit_measured_y">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>180</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="font">
+          <font>
+           <family>Courier</family>
+          </font>
+         </property>
+         <property name="text">
+          <string>xx.xx</string>
+         </property>
+         <property name="alignment">
+          <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+         </property>
+         <property name="readOnly">
+          <bool>true</bool>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="4" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_9">
+       <item>
+        <widget class="QLineEdit" name="lineEdit_measured_z">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>180</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="font">
+          <font>
+           <family>Courier</family>
+          </font>
+         </property>
+         <property name="text">
+          <string>xx.xx</string>
+         </property>
+         <property name="alignment">
+          <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+         </property>
+         <property name="readOnly">
+          <bool>true</bool>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="5" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_10">
+       <item>
+        <widget class="QLineEdit" name="lineEdit_measured_yaw">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>180</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="font">
+          <font>
+           <family>Courier</family>
+          </font>
+         </property>
+         <property name="text">
+          <string>xx.xx</string>
+         </property>
+         <property name="alignment">
+          <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+         </property>
+         <property name="readOnly">
+          <bool>true</bool>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="6" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_11">
+       <item>
+        <widget class="QLineEdit" name="lineEdit_measured_pitch">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>180</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="font">
+          <font>
+           <family>Courier</family>
+          </font>
+         </property>
+         <property name="text">
+          <string>xx.xx</string>
+         </property>
+         <property name="alignment">
+          <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+         </property>
+         <property name="readOnly">
+          <bool>true</bool>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item row="7" column="0">
+      <layout class="QHBoxLayout" name="horizontalLayout_12">
+       <item>
+        <widget class="QLineEdit" name="lineEdit_measured_roll">
+         <property name="sizePolicy">
+          <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
+           <horstretch>0</horstretch>
+           <verstretch>0</verstretch>
+          </sizepolicy>
+         </property>
+         <property name="maximumSize">
+          <size>
+           <width>180</width>
+           <height>16777215</height>
+          </size>
+         </property>
+         <property name="font">
+          <font>
+           <family>Courier</family>
+          </font>
+         </property>
+         <property name="text">
+          <string>xx.xx</string>
+         </property>
+         <property name="alignment">
+          <set>Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter</set>
+         </property>
+         <property name="readOnly">
+          <bool>true</bool>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+    </layout>
+   </item>
+  </layout>
+ </widget>
+ <resources/>
+ <connections/>
+</ui>
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/Constants_for_Qt_compile.h b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/Constants_for_Qt_compile.h
index b361da05638f8715502151fdce96166c4ea49128..716a287fcc81430b331cea1d81c4b1f750f748a9 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/Constants_for_Qt_compile.h
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/Constants_for_Qt_compile.h
@@ -114,6 +114,7 @@
 #define REMOTE_CONTROLLER    5
 #define TUNING_CONTROLLER    6
 #define PICKER_CONTROLLER    7
+#define TEMPLATE_CONTROLLER  8
 
 // The constants that "command" changes in the
 // operation state of this agent
@@ -124,6 +125,7 @@
 #define CMD_USE_REMOTE_CONTROLLER    5
 #define CMD_USE_TUNING_CONTROLLER    6
 #define CMD_USE_PICKER_CONTROLLER    7
+#define CMD_USE_TEMPLATE_CONTROLLER  8
 
 
 #define CMD_CRAZYFLY_TAKE_OFF        11
@@ -252,6 +254,7 @@
 #define LOAD_YAML_REMOTE_CONTROLLER_AGENT           5
 #define LOAD_YAML_TUNING_CONTROLLER_AGENT           6
 #define LOAD_YAML_PICKER_CONTROLLER_AGENT           7
+#define LOAD_YAML_TEMPLATE_CONTROLLER_AGENT         8
 
 #define LOAD_YAML_SAFE_CONTROLLER_COORDINATOR       11
 #define LOAD_YAML_DEMO_CONTROLLER_COORDINATOR       12
@@ -260,6 +263,7 @@
 #define LOAD_YAML_REMOTE_CONTROLLER_COORDINATOR     15
 #define LOAD_YAML_TUNING_CONTROLLER_COORDINATOR     16
 #define LOAD_YAML_PICKER_CONTROLLER_COORDINATOR     17
+#define LOAD_YAML_TEMPLATE_CONTROLLER_COORDINATOR   18
 
 
 // For sending commands to the controller node informing
@@ -276,6 +280,7 @@
 #define FETCH_YAML_REMOTE_CONTROLLER_FROM_OWN_AGENT    5
 #define FETCH_YAML_TUNING_CONTROLLER_FROM_OWN_AGENT    6
 #define FETCH_YAML_PICKER_CONTROLLER_FROM_OWN_AGENT    7
+#define FETCH_YAML_TEMPLATE_CONTROLLER_FROM_OWN_AGENT  8
 
 #define FETCH_YAML_SAFE_CONTROLLER_FROM_COORDINATOR      11
 #define FETCH_YAML_DEMO_CONTROLLER_FROM_COORDINATOR      12
@@ -283,4 +288,4 @@
 #define FETCH_YAML_MPC_CONTROLLER_FROM_COORDINATOR       14
 #define FETCH_YAML_REMOTE_CONTROLLER_FROM_COORDINATOR    15
 #define FETCH_YAML_TUNING_CONTROLLER_FROM_COORDINATOR    16
-#define FETCH_YAML_PICKER_CONTROLLER_FROM_COORDINATOR    17
\ No newline at end of file
+#define FETCH_YAML_TEMPLATE_CONTROLLER_FROM_COORDINATOR  18
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/controllertabs.h b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/controllertabs.h
index 609a68823b2f444ee5b62a07000e7a83b57b2a81..51c29e93f4ed255c09eb32e47d325e02b8a067fa 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/controllertabs.h
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/controllertabs.h
@@ -90,7 +90,7 @@ public:
     void showHideController_student_changed();
     void showHideController_picker_changed();
     void showHideController_tuning_changed();
-    void showHideController_safe_changed();
+    void showHideController_template_changed();
 
 
 public slots:
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/enablecontrollerloadyamlbar.h b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/enablecontrollerloadyamlbar.h
index babe4cba0ae49a2d0539efb161c5571b06319d22..6699aa3bfc41e1e3f414912e1cc4f45bcf5649f3 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/enablecontrollerloadyamlbar.h
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/enablecontrollerloadyamlbar.h
@@ -102,7 +102,7 @@ public:
     void showHideController_student_changed();
     void showHideController_picker_changed();
     void showHideController_tuning_changed();
-    void showHideController_safe_changed();
+    void showHideController_template_changed();
 
 
 public slots:
@@ -112,18 +112,19 @@ public slots:
 private slots:
 
     // ENABLE CONTROLLER BUTTONS ON-CLICK CALLBACK
-    void on_enable_safe_button_clicked();
-    void on_enable_tuning_button_clicked();
-    void on_enable_picker_button_clicked();
-    void on_enable_student_button_clicked();
     void on_enable_default_button_clicked();
+    void on_enable_student_button_clicked();
+    void on_enable_picker_button_clicked();
+    void on_enable_tuning_button_clicked();
+    void on_enable_template_button_clicked();
 
     // LOAD YAML BUTTONS ON-CLICK CALLBACK
-    void on_load_yaml_safe_button_clicked();
-    void on_load_yaml_tuning_button_clicked();
-    void on_load_yaml_picker_button_clicked();
-    void on_load_yaml_student_button_clicked();
     void on_load_yaml_default_button_clicked();
+    void on_load_yaml_student_button_clicked();
+    void on_load_yaml_picker_button_clicked();
+    void on_load_yaml_tuning_button_clicked();
+    void on_load_yaml_template_button_clicked();
+
 
 private:
     Ui::EnableControllerLoadYamlBar *ui;
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/mainwindow.h b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/mainwindow.h
index e1c67caf6ba3b8076c6ec8f68c601ee43cbe19dc..2cfdc26874205d9e8c51fa7c46bf24568d0b0446 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/mainwindow.h
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/mainwindow.h
@@ -131,7 +131,7 @@ private slots:
     void on_action_showHideController_student_changed();
     void on_action_showHideController_picker_changed();
     void on_action_showHideController_tuning_changed();
-    void on_action_showHideController_safe_changed();
+    void on_action_showHideController_template_changed();
 
 };
 
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/templatecontrollertab.h b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/templatecontrollertab.h
new file mode 100644
index 0000000000000000000000000000000000000000..dd781546ca9b2c43cb589061a4d811e914fe6218
--- /dev/null
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/include/templatecontrollertab.h
@@ -0,0 +1,22 @@
+#ifndef TEMPLATECONTROLLERTAB_H
+#define TEMPLATECONTROLLERTAB_H
+
+#include <QWidget>
+
+namespace Ui {
+class TemplateControllerTab;
+}
+
+class TemplateControllerTab : public QWidget
+{
+    Q_OBJECT
+
+public:
+    explicit TemplateControllerTab(QWidget *parent = 0);
+    ~TemplateControllerTab();
+
+private:
+    Ui::TemplateControllerTab *ui;
+};
+
+#endif // TEMPLATECONTROLLERTAB_H
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/controllertabs.cpp b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/controllertabs.cpp
index 39a23530c20a330a7eb9115456716404e07320f9..d3cae357ebbc4e89202babe203e2a437a7f567f2 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/controllertabs.cpp
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/controllertabs.cpp
@@ -232,9 +232,9 @@ void ControllerTabs::showHideController_tuning_changed()
     showHideController_toggle("Tuning",ui->tuning_tab);
 }
 
-void ControllerTabs::showHideController_safe_changed()
+void ControllerTabs::showHideController_template_changed()
 {
-    showHideController_toggle("Safe",ui->safe_tab);
+    showHideController_toggle("Template",ui->template_tab);
 }
 
 
@@ -384,9 +384,14 @@ void ControllerTabs::setControllerEnabled(int new_controller)
     {
         case SAFE_CONTROLLER:
         {
-            //ui->controller_enabled_label->setText("Safe");
+            setTextColourOfTabLabel( m_tab_text_colour_highlight , ui->default_tab );
             break;
         }
+//        case DEFAULT_CONTROLLER:
+//        {
+//            setTextColourOfTabLabel( m_tab_text_colour_highlight , ui->default_tab );
+//            break;
+//        }
         case DEMO_CONTROLLER:
         {
             //ui->controller_enabled_label->setText("Demo");
@@ -417,6 +422,11 @@ void ControllerTabs::setControllerEnabled(int new_controller)
             setTextColourOfTabLabel( m_tab_text_colour_highlight , ui->picker_tab );
             break;
         }
+        case TEMPLATE_CONTROLLER:
+        {
+            setTextColourOfTabLabel( m_tab_text_colour_highlight , ui->template_tab );
+            break;
+        }
         default:
         {
             //ui->controller_enabled_label->setText("Unknown");
@@ -432,7 +442,7 @@ void ControllerTabs::setAllTabLabelsToNormalColouring()
     setTextColourOfTabLabel( m_tab_text_colour_normal , ui->student_tab );
     setTextColourOfTabLabel( m_tab_text_colour_normal , ui->picker_tab );
     setTextColourOfTabLabel( m_tab_text_colour_normal , ui->tuning_tab );
-    setTextColourOfTabLabel( m_tab_text_colour_normal , ui->safe_tab );
+    setTextColourOfTabLabel( m_tab_text_colour_normal , ui->template_tab );
 }
 
 void ControllerTabs::setTextColourOfTabLabel(QColor color , QWidget * tab_widget)
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/enablecontrollerloadyamlbar.cpp b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/enablecontrollerloadyamlbar.cpp
index 14396c7098c10114c3a45cdc833ef4605d0450a9..3046875521ef6ae5351891b910063a2c27086acd 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/enablecontrollerloadyamlbar.cpp
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/enablecontrollerloadyamlbar.cpp
@@ -108,20 +108,19 @@ void EnableControllerLoadYamlBar::showHideController_tuning_changed()
     ui->load_yaml_tuning_button->setHidden( !(ui->load_yaml_tuning_button->isHidden()) );
 }
 
-void EnableControllerLoadYamlBar::showHideController_safe_changed()
+void EnableControllerLoadYamlBar::showHideController_template_changed()
 {
-    ui->enable_safe_button   ->setHidden( !(ui->enable_safe_button->isHidden()) );
-    ui->load_yaml_safe_button->setHidden( !(ui->load_yaml_safe_button->isHidden()) );
+    ui->enable_template_button   ->setHidden( !(ui->enable_template_button->isHidden()) );
+    ui->load_yaml_template_button->setHidden( !(ui->load_yaml_template_button->isHidden()) );
 }
 
 
 
 
 
-
 // ENABLE CONTROLLER BUTTONS ON-CLICK CALLBACK
 
-void EnableControllerLoadYamlBar::on_enable_safe_button_clicked()
+void EnableControllerLoadYamlBar::on_enable_default_button_clicked()
 {
 #ifdef CATKIN_MAKE
     dfall_pkg::IntWithHeader msg;
@@ -132,14 +131,14 @@ void EnableControllerLoadYamlBar::on_enable_safe_button_clicked()
 #endif
 }
 
-void EnableControllerLoadYamlBar::on_enable_tuning_button_clicked()
+void EnableControllerLoadYamlBar::on_enable_student_button_clicked()
 {
 #ifdef CATKIN_MAKE
     dfall_pkg::IntWithHeader msg;
     fillIntMessageHeader(msg);
-    msg.data = CMD_USE_TUNING_CONTROLLER;
+    msg.data = CMD_USE_STUDENT_CONTROLLER;
     this->commandPublisher.publish(msg);
-    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Enable Tuning Controller");
+    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Enable Student Controller");
 #endif
 }
 
@@ -154,39 +153,53 @@ void EnableControllerLoadYamlBar::on_enable_picker_button_clicked()
 #endif
 }
 
-void EnableControllerLoadYamlBar::on_enable_student_button_clicked()
+void EnableControllerLoadYamlBar::on_enable_tuning_button_clicked()
 {
 #ifdef CATKIN_MAKE
     dfall_pkg::IntWithHeader msg;
     fillIntMessageHeader(msg);
-    msg.data = CMD_USE_STUDENT_CONTROLLER;
+    msg.data = CMD_USE_TUNING_CONTROLLER;
     this->commandPublisher.publish(msg);
-    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Enable Student Controller");
+    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Enable Tuning Controller");
 #endif
 }
 
-void EnableControllerLoadYamlBar::on_enable_default_button_clicked()
+void EnableControllerLoadYamlBar::on_enable_template_button_clicked()
 {
 #ifdef CATKIN_MAKE
     dfall_pkg::IntWithHeader msg;
     fillIntMessageHeader(msg);
-    msg.data = CMD_USE_SAFE_CONTROLLER;
+    msg.data = CMD_USE_TEMPLATE_CONTROLLER;
     this->commandPublisher.publish(msg);
-    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Enable Safe Controller");
+    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Enable Template Controller");
 #endif
 }
 
 
+
+
+
+
+
 // LOAD YAML BUTTONS ON-CLICK CALLBACK
 
-void EnableControllerLoadYamlBar::on_load_yaml_safe_button_clicked()
+void EnableControllerLoadYamlBar::on_load_yaml_default_button_clicked()
 {
-#ifdef CATKIN_MAKE
-
+    #ifdef CATKIN_MAKE
+    // Create a local variable for the message
+    dfall_pkg::StringWithHeader yaml_filename_msg;
+    // Set for whom this applies to
+    fillStringMessageHeader(yaml_filename_msg);
+    // Specify the data
+    yaml_filename_msg.data = "DefaultController";
+    // Send the message
+    m_requestLoadYamlFilenamePublisher.publish(yaml_filename_msg);
+    // Inform the user that the menu item was selected
+    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Load Default Controller YAML was clicked.");
 #endif
 }
 
-void EnableControllerLoadYamlBar::on_load_yaml_tuning_button_clicked()
+void EnableControllerLoadYamlBar::on_load_yaml_student_button_clicked()
 {
 #ifdef CATKIN_MAKE
     // Create a local variable for the message
@@ -194,11 +207,11 @@ void EnableControllerLoadYamlBar::on_load_yaml_tuning_button_clicked()
     // Set for whom this applies to
     fillStringMessageHeader(yaml_filename_msg);
     // Specify the data
-    yaml_filename_msg.data = "TuningController";
+    yaml_filename_msg.data = "StudentController";
     // Send the message
     m_requestLoadYamlFilenamePublisher.publish(yaml_filename_msg);
     // Inform the user that the menu item was selected
-    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Load Tuning Controller YAML was clicked.");
+    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Load Student Controller YAML was clicked.");
 #endif
 }
 
@@ -218,7 +231,7 @@ void EnableControllerLoadYamlBar::on_load_yaml_picker_button_clicked()
 #endif
 }
 
-void EnableControllerLoadYamlBar::on_load_yaml_student_button_clicked()
+void EnableControllerLoadYamlBar::on_load_yaml_tuning_button_clicked()
 {
 #ifdef CATKIN_MAKE
     // Create a local variable for the message
@@ -226,27 +239,27 @@ void EnableControllerLoadYamlBar::on_load_yaml_student_button_clicked()
     // Set for whom this applies to
     fillStringMessageHeader(yaml_filename_msg);
     // Specify the data
-    yaml_filename_msg.data = "StudentController";
+    yaml_filename_msg.data = "TuningController";
     // Send the message
     m_requestLoadYamlFilenamePublisher.publish(yaml_filename_msg);
     // Inform the user that the menu item was selected
-    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Load Student Controller YAML was clicked.");
+    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Load Tuning Controller YAML was clicked.");
 #endif
 }
 
-void EnableControllerLoadYamlBar::on_load_yaml_default_button_clicked()
+void EnableControllerLoadYamlBar::on_load_yaml_template_button_clicked()
 {
-    #ifdef CATKIN_MAKE
+#ifdef CATKIN_MAKE
     // Create a local variable for the message
     dfall_pkg::StringWithHeader yaml_filename_msg;
     // Set for whom this applies to
     fillStringMessageHeader(yaml_filename_msg);
     // Specify the data
-    yaml_filename_msg.data = "DefaultController";
+    yaml_filename_msg.data = "TemplateController";
     // Send the message
     m_requestLoadYamlFilenamePublisher.publish(yaml_filename_msg);
     // Inform the user that the menu item was selected
-    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Load Default Controller YAML was clicked.");
+    ROS_INFO("[ENABLE CONTROLLER LOAD YAML GUI BAR] Load Template Controller YAML was clicked.");
 #endif
 }
 
@@ -254,6 +267,7 @@ void EnableControllerLoadYamlBar::on_load_yaml_default_button_clicked()
 
 
 
+
 //    ----------------------------------------------------------------------------------
 //      A     GGGG  EEEEE  N   N  TTTTT     III  DDDD    SSSS
 //     A A   G      E      NN  N    T        I   D   D  S
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/templatecontrollertab.cpp b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/templatecontrollertab.cpp
new file mode 100644
index 0000000000000000000000000000000000000000..f16cdf5d33562d75da924c1fb9ca6f181b7dceb8
--- /dev/null
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/templatecontrollertab.cpp
@@ -0,0 +1,14 @@
+#include "templatecontrollertab.h"
+#include "ui_templatecontrollertab.h"
+
+TemplateControllerTab::TemplateControllerTab(QWidget *parent) :
+    QWidget(parent),
+    ui(new Ui::TemplateControllerTab)
+{
+    ui->setupUi(this);
+}
+
+TemplateControllerTab::~TemplateControllerTab()
+{
+    delete ui;
+}
diff --git a/dfall_ws/src/dfall_pkg/include/nodes/Constants.h b/dfall_ws/src/dfall_pkg/include/nodes/Constants.h
index fd4d1d4fcf29c6b76782f79f803ec6f93bd7a988..71507435e23d2c1117e1cd90460ea14815821c42 100644
--- a/dfall_ws/src/dfall_pkg/include/nodes/Constants.h
+++ b/dfall_ws/src/dfall_pkg/include/nodes/Constants.h
@@ -127,6 +127,7 @@
 #define REMOTE_CONTROLLER    5
 #define TUNING_CONTROLLER    6
 #define PICKER_CONTROLLER    7
+#define TEMPLATE_CONTROLLER  8
 
 // The constants that "command" changes in the
 // operation state of this agent
@@ -137,6 +138,7 @@
 #define CMD_USE_REMOTE_CONTROLLER    5
 #define CMD_USE_TUNING_CONTROLLER    6
 #define CMD_USE_PICKER_CONTROLLER    7
+#define CMD_USE_TEMPLATE_CONTROLLER  8
 
 
 #define CMD_CRAZYFLY_TAKE_OFF        11
@@ -266,6 +268,7 @@
 #define LOAD_YAML_REMOTE_CONTROLLER_AGENT           5
 #define LOAD_YAML_TUNING_CONTROLLER_AGENT           6
 #define LOAD_YAML_PICKER_CONTROLLER_AGENT           7
+#define LOAD_YAML_TEMPLATE_CONTROLLER_AGENT         7
 
 #define LOAD_YAML_SAFE_CONTROLLER_COORDINATOR       11
 #define LOAD_YAML_DEMO_CONTROLLER_COORDINATOR       12
@@ -274,6 +277,7 @@
 #define LOAD_YAML_REMOTE_CONTROLLER_COORDINATOR     15
 #define LOAD_YAML_TUNING_CONTROLLER_COORDINATOR     16
 #define LOAD_YAML_PICKER_CONTROLLER_COORDINATOR     17
+#define LOAD_YAML_TEMPLATE_CONTROLLER_COORDINATOR   18
 
 
 // For sending commands to the controller node informing
@@ -290,6 +294,7 @@
 #define FETCH_YAML_REMOTE_CONTROLLER_FROM_OWN_AGENT    5
 #define FETCH_YAML_TUNING_CONTROLLER_FROM_OWN_AGENT    6
 #define FETCH_YAML_PICKER_CONTROLLER_FROM_OWN_AGENT    7
+#define FETCH_YAML_TEMPLATE_CONTROLLER_FROM_OWN_AGENT  8
 
 #define FETCH_YAML_SAFE_CONTROLLER_FROM_COORDINATOR      11
 #define FETCH_YAML_DEMO_CONTROLLER_FROM_COORDINATOR      12
@@ -297,4 +302,5 @@
 #define FETCH_YAML_MPC_CONTROLLER_FROM_COORDINATOR       14
 #define FETCH_YAML_REMOTE_CONTROLLER_FROM_COORDINATOR    15
 #define FETCH_YAML_TUNING_CONTROLLER_FROM_COORDINATOR    16
-#define FETCH_YAML_PICKER_CONTROLLER_FROM_COORDINATOR    17
\ No newline at end of file
+#define FETCH_YAML_PICKER_CONTROLLER_FROM_COORDINATOR    17
+#define FETCH_YAML_TEMPLATE_CONTROLLER_FROM_COORDINATOR  18
\ No newline at end of file
diff --git a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/mainwindow.cpp b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/mainwindow.cpp
index 254a0907e11221a8dddde97fac20f2568009a016..239aa269a5e2794a8fc7daffe14aa0405ce65040 100644
--- a/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/mainwindow.cpp
+++ b/dfall_ws/src/dfall_pkg/GUI_Qt/flyingAgentGUI/src/mainwindow.cpp
@@ -145,9 +145,8 @@ MainWindow::MainWindow(int argc, char **argv, QWidget *parent) :
     ui->action_showHideController_picker->trigger();
     // > For the tuning controller
     ui->action_showHideController_tuning->trigger();
-    // > For the safe controller
-    ui->action_showHideController_safe->trigger();
-
+    // > For the template controller
+    ui->action_showHideController_template->trigger();
 
 }
 
@@ -246,11 +245,11 @@ void MainWindow::on_action_showHideController_tuning_changed()
     ui->customWidget_controller_tabs->showHideController_tuning_changed();
 }
 
-void MainWindow::on_action_showHideController_safe_changed()
+void MainWindow::on_action_showHideController_template_changed()
 {
     // Notify the UI elements of this change
-    ui->customWidget_enableControllerLoadYamlBar->showHideController_safe_changed();
-    ui->customWidget_controller_tabs->showHideController_safe_changed();
+    ui->customWidget_enableControllerLoadYamlBar->showHideController_template_changed();
+    ui->customWidget_controller_tabs->showHideController_template_changed();
 }
 
 